@@ -11,11 +11,11 @@ import type_case
 
 from client import connect, get_client
 
-from mix.dict import Dict
-from mix.set import Set
-from mix.sorted_set import SortedSet
-from mix.string import String
-from mix.counter import Counter
-from mix.deque import Deque
+from key.dict import Dict
+from key.set import Set
+from key.sorted_set import SortedSet
+from key.string import String
+from key.counter import Counter
+from key.deque import Deque
 
-__version__ = "1.9.0"
+__version__ = "1.9.1"
